C
C SUBROUTINE 'STR_ADDS'
C =====================
C
C ADD A CHARACTER STRING 'NB' SPACES AFTER THE LAST NON-BLANK CHARACTER
C OF ANOTHER CHARACTER STRING
C
      SUBROUTINE STR_ADDS (STR, STR2, NB)
C
C PARAMETERS
C
C      STR   (I/O)    CHARACTER STRING TO WHICH THE SECOND STRING IS
C                     TO BE APPENDED
C      STR2  (I)      THE CHARACTER STRING TO BE APPENDED
C      NB    (I)      THE NUMBER OF BLANKS REQUIRED AFTER THE LAST NON-BLANK
C                     CHARACTER OF THE STRING BEFORE ADDING STR2 (MAY BE 0)
C
C SPECIFICATION STATEMENTS
C ------------------------
C
      CHARACTER*(*) STR, STR2
C
C ADD STRING
C ----------
C
      LL = LEN(STR) 
      DO 100 L=LL,1,-1
      IF (STR(L:L).NE.' ') THEN
         LSTR = L
         GO TO 200
      END IF
100   CONTINUE
      LSTR = 0
200   IF (LSTR+1+NB.GT.LL) RETURN
      STR(LSTR+1+NB:) = STR2
      RETURN
      END
